#!/bin/sh
set -uf

if [ -z ${GRAFANA_HOST+x} ]; then GRAFANA_HOST="localhost"; fi
if [ -z ${GRAFANA_PORT+x} ]; then GRAFANA_PORT="3000"; fi
if [ -z ${GRAFANA_USER+x} ]; then GRAFANA_USER="admin"; fi
if [ -z ${GRAFANA_PASSWORD+x} ]; then GRAFANA_PASSWORD="admin"; fi

DATASOURCE_UID=$(curl -sS -XGET -H "Content-type: application/json" \
  ${GRAFANA_USER}:${GRAFANA_PASSWORD}@${GRAFANA_HOST}:${GRAFANA_PORT}/api/datasources \
  | jq -r '.[] | select(.name == "monitoring") | .uid') \
  || { echo "could not find a 'monitoring' datasource, please create one" ; exit 1; }

if [ -z "${DATASOURCE_UID}" ]; \
  then { echo "could not find a 'monitoring' datasource, please create one" ; exit 1; } fi

curl -sS -XPOST -H "Content-type: application/json" -d '{"title": "SingleStore Alerts", "uid": "singlestore_alerts"}' \
  ${GRAFANA_USER}:${GRAFANA_PASSWORD}@${GRAFANA_HOST}:${GRAFANA_PORT}/api/folders > /dev/null \
  || { echo 'could not create an alert rule directory' ; exit 1; }

set -- "Memory_Utilization" "Disk_Utilization" "Partitions_unavailable" "CPU_Utilization"

for file in "$@"; do
  curl -sS -XPOST -H "Content-type: application/json" -H "X-Disable-Provenance: true" \
  -d "$(sed "s/DATASOURCE_UID/$DATASOURCE_UID/g" ./$file.json)" \
  ${GRAFANA_USER}:${GRAFANA_PASSWORD}@${GRAFANA_HOST}:${GRAFANA_PORT}/api/v1/provisioning/alert-rules > /dev/null \
  || { echo "alert rule $file could not be provisioned" ;}
done